@@ -1,7 +1,7 @@
 package Pcore::App::API::Auth::Request;
 
 use Pcore -class, -res;
-use Pcore::Util::Scalar qw[is_blessed_ref];
+use Pcore::Util::Scalar qw[is_res];
 
 use overload    #
   q[&{}] => sub ( $self, @ ) {
@@ -9,9 +9,9 @@ use overload    #
   },
   fallback => 1;
 
-has auth       => ();    # ( is => 'ro', isa => InstanceOf ['Pcore::App::API::Auth'], required => 1 );
-has _cb        => ();    # ( is => 'ro', isa => Maybe [CodeRef] );
-has _responded => 0;     # ( is => 'ro', isa => Bool, default => 0, init_arg => undef );    # already responded
+has auth       => ( required => 1 );       # InstanceOf ['Pcore::App::API::Auth']
+has _cb        => ();                      # Maybe [CodeRef]
+has _responded => 0, init_arg => undef;    # Bool, already responded
 
 sub DESTROY ( $self ) {
     if ( ( ${^GLOBAL_PHASE} ne 'DESTRUCT' ) && !$self->{_responded} && $self->{_cb} ) {
@@ -23,9 +23,7 @@ sub DESTROY ( $self ) {
     return;
 }
 
-sub IS_CALLBACK ($self) {
-    return 1;
-}
+sub IS_PCORE_CALLBACK ($self) { return 1 }
 
 sub api_can_call ( $self, $method_id, $cb ) {
     $self->{auth}->api_can_call( $method_id, $cb );
@@ -46,7 +44,7 @@ sub _respond ( $self, @ ) {
     if ( my $cb = delete $self->{_cb} ) {
 
         # return response, if callback is defined
-        $cb->( is_blessed_ref $_[1] ? $_[1] : res splice @_, 1 );
+        $cb->( is_res $_[1] ? $_[1] : res splice @_, 1 );
     }
 
     return;
